Event
=====

.. currentmodule:: pqp.symbols

.. autoclass:: Event
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Event.get_var

   .. rubric:: Attributes Documentation

   .. autoattribute:: get_var
